"""Goodman CCD Reduction Tool

"""

from .goodman_ccd import ReduceCCD, get_args
from .image_processor import ImageProcessor
